@@ -1,17 +1,8 @@
 /*
- * Copyright (C) 2002 Jean-Baptiste Mardelle <bj@altern.org>
- * Copyright (C) 2007,2008,2009,2010,2011,2012
- *               Rolf Eike Beer <kde@opensource.sf-tec.de>
- */
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2002 Jean-Baptiste Mardelle <bj@altern.org>
+    SPDX-FileCopyrightText: 2007, 2008, 2009, 2010, 2011, 2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kgpgtextinterface.h"
 
@@ -23,6 +14,7 @@
 
 class KGpgTextInterfacePrivate
 {
+	Q_DISABLE_COPY(KGpgTextInterfacePrivate)
 public:
 	KGpgTextInterfacePrivate(QObject *parent, const QString &keyID, const QStringList &options);
 
@@ -101,5 +93,5 @@ KGpgTextInterface::slotSignFile()
 void
 KGpgTextInterface::slotSignFinished()
 {
-	emit fileSignFinished();
+	Q_EMIT fileSignFinished();
 }
